@@ -319,8 +319,13 @@ def _load_configs_for_credentials():
     config_values["project_name"] = (project_config.get("project_name")
                                          or terraform_config.get("project_long"))
 
-    config_values["primary_region"] = (project_config.get("primary_region")
-                                           or terraform_config.get("region_primary")
+    # region_primary was added in refarch v1
+    # for v2 it was replaced by region at project level
+    region_primary = 'region_primary'
+    if not 'region_primary' in project_config and not 'region_primary' in terraform_config:
+        region_primary = 'region'
+    config_values["primary_region"] = (project_config.get(region_primary)
+                                           or terraform_config.get(region_primary)
                                            or _ask_for_region())
     config_values["secondary_region"] = terraform_config.get("region_secondary")
 
