@@ -12,6 +12,7 @@ from ruamel.yaml import YAML
 from jinja2 import Environment
 from jinja2 import FileSystemLoader
 
+from leverage import __toolbox_version__
 from leverage import logger
 from leverage.logger import console
 from leverage.path import get_root_path
@@ -203,6 +204,8 @@ def _render_templates(template_files, config, source=TEMPLATE_DIR, destination=P
         template_location = template_file.relative_to(TEMPLATES_REPO_DIR)
 
         template = JINJA_ENV.get_template(template_location.as_posix())
+        if not 'terraform_image_tag' in config:
+            config['terraform_image_tag'] = __toolbox_version__
         rendered_template = template.render(config)
 
         rendered_location = template_file.relative_to(source)
